Summary:        Process Management Interface Exascale (PMIx)
Name:           pmix
Version:        5.0.3
Release:        1%{?dist}
License:        BSD
URL:            https://pmix.org/
Source0:        https://github.com/openpmix/openpmix/releases/download/v%{version}/%{name}-%{version}.tar.bz2


BuildRequires:  autoconf automake gcc libtool make
BuildRequires:  flex hwloc-devel libevent-devel munge-devel perl-interpreter zlib-devel

%description
The Process Management Interface (PMI) has been used for quite some time as
a means of exchanging wireup information needed for interprocess
communication. Two versions (PMI-1 and PMI-2) have been released as part of
the MPICH effort. While PMI-2 demonstrates better scaling properties than its
PMI-1 predecessor, attaining rapid launch and wireup of the roughly 1M
processes executing across 100k nodes expected for exascale operations remains
challenging.
PMI Exascale (PMIx) represents an attempt to resolve these questions by
providing an extended version of the PMI standard specifically designed to
support clusters up to and including exascale sizes. The overall objective of
the project is not to branch the existing pseudo-standard definitions - in
fact, PMIx fully supports both of the existing PMI-1 and PMI-2 APIs - but
rather to (a) augment and extend those APIs to eliminate some current
restrictions that impact scalability, and (b) provide a reference
implementation of the PMI-server that demonstrates the desired level of
scalability.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-tools = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        tools
Summary:        Tools for %{name}
Requires:       %{name} = %{version}-%{release}

%description    tools
The %{name}-tools package contains for use with PMIx-based RMs and language-
based starters (e.g., mpirun).
* pinfo - show MCA params, build info, etc.
* pps - get list of active nspaces, retrieve status of jobs/nodes/procs
* pevent - inject an event into the system

%prep
%autosetup -n %{name}-%{version} -p1
find src -name \*.l -print -exec touch --no-create {} \;

%build
%{_builddir}/%{name}-%{version}/autogen.pl
export CFLAGS="%{build_cflags} -Wno-unused-function -Wno-attributes"
%configure \
    --prefix=%{_prefix} \
    --sysconfdir=%{_sysconfdir}/%{name} \
    --disable-static \
    --disable-silent-rules \
    --enable-shared \
    --with-munge

%make_build

%check
%make_build check

%install
%make_install
find %{buildroot} -name '*.la' -delete

 
%files
%license LICENSE
%doc README
%dir %{_datadir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%{_datadir}/%{name}/*.txt
%{_libdir}/libpmix.so.2*
%{_libdir}/%{name}/*.so
%{_mandir}/man1/*.1*
 
%files devel
%{_datadir}/%{name}/*.supp
%{_includedir}/pmix*.h
%{_libdir}/libpmix.so
%{_libdir}/pkgconfig/*.pc
 
%files tools
%{_bindir}/*
 
%changelog
* Fri Jul 19 2024 Upgrade Robot <upbot@opencloudos.tech> - 5.0.3-1
- Upgrade to version 5.0.3

* Thu Oct 19 2023 Miaojun Dong <zoedong@tencent.com> - 4.1.2-5
- Fix CVE-2023-41915

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.1.2-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.1.2-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.1.2-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Nov 22 2022 Miaojun Dong <zoedong@tencent.com> - 4.1.2-1
- Initial build

